@@ -1,11 +1,11 @@
 use strict;
 use warnings;
-package Dist::Zilla::PluginBundle::Author::ETHER; # git description: v0.169-2-geff4520
+package Dist::Zilla::PluginBundle::Author::ETHER; # git description: v0.170-5-g5c9fcaa
 # vim: set ts=8 sts=2 sw=2 tw=100 et :
 # ABSTRACT: A plugin bundle for distributions built by ETHER
 # KEYWORDS: author bundle distribution tool
 
-our $VERSION = '0.170';
+our $VERSION = '0.171';
 
 use Moose;
 with
@@ -658,12 +658,11 @@ around add_bundle => sub {
 
 # patch around broken Dist::Zilla 6.034+
 # known affected modules:
-# Dist::Zilla::App::Command::alldeps
 # Dist::Zilla::App::Command::stale
 # Dist::Zilla::Plugin::EnsurePrereqsInstalled
 # Dist::Zilla::Plugin::Prereqs::AuthorDeps
 # Dist::Zilla::Plugin::PromptIfStale
-require Dist::Zilla::Util::AuthorDeps;
++require Dist::Zilla::Util::AuthorDeps;
 *Dist::Zilla::Util::AuthorDeps::extract_author_deps = \&Dist::Zilla::Util::AuthorDeps::_extract_author_deps
   if eval { Dist::Zilla::Util::AuthorDeps->VERSION(6.034); 1 }
     and not Dist::Zilla::Util::AuthorDeps->can('extract_author_deps');
@@ -682,7 +681,7 @@ Dist::Zilla::PluginBundle::Author::ETHER - A plugin bundle for distributions bui
 
 =head1 VERSION
 
-version 0.170
+version 0.171
 
 =head1 SYNOPSIS
 
